EpubHighlight class

Constructors

EpubHighlight({required String cfi, required String text, required String color, required double opacity})
EpubHighlight.fromJson(Map<String, dynamic> json)
factory

Properties

cfi String
The CFI string of the highlight location
final
color String
The color of the highlight
final
hashCode int
The hash code for this object.
no setterinherited
opacity double
The opacity of the highlight
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text that is highlighted
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited